@@ -61,7 +61,7 @@ subroutine input(aheadinput,ajname,adate,kp,crys,syms,gvec, &
   integer :: itpv,itpc,iv,nqnonzero,nrkq,myipe,ipool
   integer :: nmtx,nmtx_l,npairs
   integer :: Nrod,Nplane,Nfft(3),dNfft(3),dkmax(3),nmpinode
-  real(DP) :: qk(3),vcell,qtot
+  real(DP) :: qk(3),vcell,qtot,norm
   real(DP) :: mem,fmem,rmem,rmem2,smem,scale,dscale
   real(DP), allocatable :: energies(:,:,:)
   logical :: dont_read
@@ -912,15 +912,16 @@ subroutine input(aheadinput,ajname,adate,kp,crys,syms,gvec, &
       1x,'eV',/,1x,'ecdel =',f10.6,/,1x,'ec0   =',f10.6,1x,'eV',/)
     
     do iq=1,pol%nq
+      norm=sqrt(DOT_PRODUCT(MATMUL(crys%bdot, pol%qpt(:,iq)),pol%qpt(:,iq)))
       if (indexq0.eq.iq) then
-        write(6,925) (pol%qpt(jj,iq),jj=1,3),q0norm
+        write(6,925) (pol%qpt(jj,iq),jj=1,3),norm
       else
-        write(6,926) (pol%qpt(jj,iq),jj=1,3)
+        write(6,926) (pol%qpt(jj,iq),jj=1,3),norm
       endif
     enddo
     write(6,*)
 925 format(1x,'Q0 and |Q0| =',4f10.6)
-926 format(1x,'Q =',3f10.6)
+926 format(1x,'Q  and |Q|  =',4f10.6)
 
   endif
 
