@@ -8,83 +8,7 @@
 
    based on marching cubes and marching tetrahedra codes by P. Bourke
    http://local.wasp.uwa.edu.au/~pbourke/geometry/polygonise/
-
---------------------------------------------------------------------------------
-
-   input file                    |   example (HOMO of benzene)
-
-   header text                   |   header C6H6_band_15
-   inputfilename file            |   inputfilename C6H6.b_15.cube
-   inputfileformat cube|xsf      |   inputfileformat cube
-   outputfilename file           |   outputfilename C6H6.b_15.pov
-   outputfileformat povray       |   outputfileformat povray
-   isovalue (0.0,1.0)            |   isovalue 0.9
-   sign positive|negative|both   |   sign both
-   power 0|1|2                   |   power 1
-   algorithm cube|tetrahedron    |   algorithm cube
-   smooth T|F                    |   smooth T
-   box T|F                       |   box F
-   basis T|F                     |   basis F
-   uc T|F                        |   uc F
-   uco                           |   uco
-   <ucox> <ucoy> <ucoz>          |   0.0 0.0 0.0
-   ucv                           |   ucv
-   <ucv1x> <ucv1y> <ucv1z>       |   1.0 0.0 0.0
-   <ucv2x> <ucv2y> <ucv2z>       |   0.0 1.0 0.0
-   <ucv3x> <ucv3y> <ucv3z>       |   0.0 0.0 1.0
-   ucu bohr|angstrom|latvec      |   ucu latvec
-   sc T|F                        |   sc T
-   sco                           |   sco
-   <scox> <scoy> <scoz>          |   -0.5 -0.5 -0.5
-   scv                           |   scv
-   <scv1x> <scv1y> <scv1z>       |   1.0 0.0 0.0
-   <scv2x> <scv2y> <scv2z>       |   0.0 1.0 0.0
-   <scv3x> <scv3y> <scv3z>       |   0.0 0.0 1.0
-   scu bohr|angstrom|latvec      |   scu latvec
-   sct T|F                       |   sct T
-
---------------------------------------------------------------------------------
-
-   the isosurface is defined by isovalue * max |psi| for power = 0 and by
-   integral_v |psi|^power = isovalue * integral |psi|^power for power > 0
-   where psi is the scalar field and v is the volume inside the isosurface
-
-   note that espresso already outputs |psi|^2, setting power = 2 yields
-   |psi|^4 in this case, to produce |psi|^2 isosurface set power = 1
-
-   algorithm stands for marching cubes and marching tetrahedra
-   smooth defines whether to average normals for smooth rendering
-
-   box specifies whether to generate supercell box in povray script
-   basis specifies whether to generate coordinate axes in povray script
-
-   sfo = scalar field origin    sfv = scalar field vectors
-   uco = unit cell origin    ucv = unit cell vectors    ucu = unit cell units
-   sco = supercell origin    scv = supercell vectors    scu = supercell units
-   sct = supercell translational symmetry
-
-   sfo/sfv are read from volumetric file
-
-   if uc = T then uco/ucv are read from parameter file
-             else uco/ucv are set to sfo/sfv
-   if sc = T then sco/scv are read from parameter file
-             else sco/scv are set to uco/ucv
-   if uc = T and ucu = latvec then uco/ucv are scaled by sfv
-   if sc = T and scu = latvec then sco/scv are scaled by ucv
-
-   if sct = T then scv is used for translational symmetry
-              else ucv is used for translational symmetry
-
-   in most cases, set uc = F (uc = T is only needed if volumetric data
-   do not span the whole unit cell and the supercell is being used, so
-   the correct unit cell must be defined)
-
-   use sc = T to construct the supercell spanning several unit cells or
-   to assemble the unit cell around the origin of the coordinate system
-   as in benzene example above (sco = (-0.5 -0.5 -0.5) in latvec units)
-
-   the supercell may span a fractional number of unit cells, in this case
-   set sct = F to produce the correct bonds at the faces of the supercell
+   See surface.inp for details on input file.
 
 ------------------------------------------------------------------------------*/
 
